@@ -1,9 +1,11 @@
+import re
 import typing as T
 import time
 import orjson
 from devtools import debug
 import edgedb
 from .span import safe_span
+from .constants import RE_CODE
 
 MUTATION_ACTIONS = ["insert ", "update ", "delete "]
 
@@ -20,6 +22,31 @@ def operation_from_query_str(query_str: str) -> str:
     return "query"
 
 
+def simplify_vars(
+    query_str: str, variables: dict[str, T.Any]
+) -> (str, dict[str, T.Any]):
+    new_vars = {}
+    new_query_str = query_str + ";"
+    for key, val in variables.items():
+        if key in new_query_str:
+            # strip key and add number to it
+            stripped_key = key.split(RE_CODE)[0]
+            i = 0
+            while True:
+                stripped_key_temp = stripped_key + f'{"" if i == 0 else i}'
+                if stripped_key_temp not in new_vars:
+                    stripped_key = stripped_key_temp
+                    break
+                i += 1
+            new_vars[stripped_key] = val
+            new_query_str = re.sub(
+                rf"(\$)({key})(\W)", r"\1" + stripped_key + r"\3", new_query_str
+            )
+    if new_query_str[-1] == ";":
+        new_query_str = new_query_str[0:-1]
+    return new_query_str, new_vars
+
+
 async def query(
     client: edgedb.AsyncIOClient,
     query_str: str,
@@ -32,6 +59,7 @@ async def query(
     """Returns a json str to be parsed by pydantic raw. Errors are raised by the lib!"""
     if not variables:
         variables = {}
+    query_str, variables = simplify_vars(query_str, variables)
     query_func = client.query_json if not only_one else client.query_single_json
     start = time.time()
     try:
