@@ -581,6 +581,7 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
         filtered_resolver: "ResolverType",
         batch: Batch = None,
         given_client: edgedb.AsyncIOClient = None,
+        only_one: bool = False,
     ) -> T.Optional[T.List[ThisNodeType]]:
         if batch:
             batch.add(
@@ -593,13 +594,22 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
                 client=given_client or cls.db_client,
                 query_str=filtered_resolver.full_delete_str(),
                 variables=filtered_resolver._get_nested_query_variables(),
-                only_one=False,
+                only_one=only_one,
             )
-        with safe_span(op=f"parse.{cls._model_name}", description=f"{len(raw_d)=}"):
-            nodes = [filtered_resolver.parse_nested_obj(d) for d in raw_d]
-        for node in nodes:
+
+        def parse_deleted(inner_d: dict) -> ThisNodeType:
+            node = filtered_resolver.parse_nested_obj(inner_d)
             node._deleted = True
-        return nodes
+            return node
+
+        with safe_span(
+            op=f"parse.{cls._model_name}",
+            description=f"only_one:{only_one}, {len(raw_d)=}",
+        ):
+            if only_one:
+                return parse_deleted(raw_d)
+            else:
+                return [parse_deleted(d) for d in raw_d]
 
     @classmethod
     def build_update_d_from_patch(cls, patch: PatchType) -> dict:
