@@ -131,13 +131,13 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     @property
     def _limit_str(self) -> str:
-        if not self._limit:
+        if self._limit is None:
             return ""
         return f"LIMIT {self._limit}"
 
     @property
     def _offset_str(self) -> str:
-        if not self._offset:
+        if self._offset is None:
             return ""
         return f"OFFSET {self._offset}"
 
@@ -308,7 +308,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         return self
 
     def limit(self: ThisResolverType, /, _: T.Optional[int]) -> ThisResolverType:
-        if self._limit:
+        if self._limit is not None:
             raise ResolverException(
                 f"Limit of {self._limit} has already been provided."
             )
@@ -316,7 +316,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         return self
 
     def offset(self: ThisResolverType, /, _: T.Optional[int]) -> ThisResolverType:
-        if self._offset:
+        if self._offset is not None:
             raise ResolverException(
                 f"Offset of {self._offset} has already been provided."
             )
@@ -379,9 +379,9 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             s += f" {self._filter_str}"
         if self._order_by:
             s += f" {self._order_by_str}"
-        if self._offset:
+        if self._offset is not None:
             s += f" {self._offset_str}"
-        if self._limit:
+        if self._limit is not None:
             s += f" {self._limit_str}"
         return s
 
